@@ -2,7 +2,10 @@ from typing import Any, Callable, Dict, List, Tuple, Union, Optional, Awaitable
 import asyncio
 import logging
 from contextlib import asynccontextmanager
+from dotenv import load_dotenv
+from fastapi import FastAPI
 from pydantic import BaseModel
+import yaml
 from sycommon.config.Config import SingletonMeta
 from sycommon.models.mqlistener_config import RabbitMQListenerConfig
 from sycommon.models.mqsend_config import RabbitMQSendConfig
@@ -16,19 +19,21 @@ class Services(metaclass=SingletonMeta):
     _registered_senders: List[str] = []
     _mq_tasks: List[asyncio.Task] = []
     _pending_setup: Optional[Callable[..., Awaitable[None]]] = None
+    _instance: Optional['Services'] = None
 
     def __init__(self, config):
         if not Services._config:
             Services._config = config
-            RabbitMQService.init(config)
+        Services._instance = self
 
     @classmethod
     def get_lifespan(cls, config):
         """返回 FastAPI 的 lifespan 管理器"""
+        cls._config = config
+
         @asynccontextmanager
         async def lifespan(app):
             # 应用启动时初始化
-            cls._config = config
             cls._loop = asyncio.get_running_loop()
             cls._initialized = True
             logging.info("Services initialized with FastAPI event loop")
@@ -51,8 +56,38 @@ class Services(metaclass=SingletonMeta):
 
         return lifespan
 
-    def plugins(
+    @classmethod
+    def plugins(cls,
+                middleware: Optional[Tuple[Callable, FastAPI]] = None,
+                nacos_service: Optional[Callable] = None,
+                logging_service: Optional[Callable] = None,
+                database_service: Optional[Union[Tuple[Callable, str],
+                                                 List[Tuple[Callable, str]]]] = None,
+                rabbitmq_listeners: Optional[List[RabbitMQListenerConfig]] = None,
+                rabbitmq_senders: Optional[List[RabbitMQSendConfig]] = None
+                ) -> None:
+        """
+        类方法：注册各种服务插件
+        确保单例实例存在后调用实例方法的register_plugins
+        """
+        # 确保实例已创建
+        if not cls._instance:
+            if not cls._config:
+                raise ValueError("Services尚未初始化，请先提供配置")
+            cls._instance = Services(cls._config)
+
+        cls._instance.register_plugins(
+            middleware=middleware,
+            nacos_service=nacos_service,
+            logging_service=logging_service,
+            database_service=database_service,
+            rabbitmq_listeners=rabbitmq_listeners,
+            rabbitmq_senders=rabbitmq_senders
+        )
+
+    def register_plugins(
         self,
+        middleware: Optional[Tuple[Callable, FastAPI]] = None,
         nacos_service: Optional[Callable] = None,
         logging_service: Optional[Callable] = None,
         database_service: Optional[Union[Tuple[Callable,
@@ -60,8 +95,10 @@ class Services(metaclass=SingletonMeta):
         rabbitmq_listeners: Optional[List[RabbitMQListenerConfig]] = None,
         rabbitmq_senders: Optional[List[RabbitMQSendConfig]] = None
     ) -> None:
-        """注册各种服务插件"""
+        """实例方法：实际执行各种服务插件的注册逻辑"""
         # 注册非异步服务
+        if middleware:
+            self._setup_middleware(middleware)
         if nacos_service:
             nacos_service(self._config)
         if logging_service:
@@ -69,6 +106,8 @@ class Services(metaclass=SingletonMeta):
         if database_service:
             self._setup_database(database_service)
 
+        RabbitMQService.init(self._config)
+
         # MQ设置异步函数
         async def setup_mq_components():
             if rabbitmq_senders:
@@ -87,6 +126,11 @@ class Services(metaclass=SingletonMeta):
             for db_setup, db_name in database_service:
                 db_setup(self._config, db_name)
 
+    def _setup_middleware(self, middleware):
+        if isinstance(middleware, tuple):
+            middleware_setup, app = middleware
+            middleware_setup(app, self._config)
+
     def _setup_senders(self, rabbitmq_senders):
         Services._registered_senders = [
             sender.queue_name for sender in rabbitmq_senders]
