@@ -46,7 +46,7 @@ from sycommon.synacos.nacos_service import NacosService
 #         return None
 
 
-def feign_client(service_name: str, path_prefix: str = ""):
+def feign_client(service_name: str, path_prefix: str = "", default_timeout: float | None = None):
     # Feign风格客户端装饰器
     """声明式HTTP客户端装饰器"""
     def decorator(cls):
@@ -56,6 +56,7 @@ def feign_client(service_name: str, path_prefix: str = ""):
                 self.nacos_manager = NacosService(None)
                 self.path_prefix = path_prefix
                 self.session = aiohttp.ClientSession()
+                self.default_timeout = default_timeout
 
             def __getattr__(self, name):
                 func = getattr(cls, name)
@@ -67,6 +68,8 @@ def feign_client(service_name: str, path_prefix: str = ""):
                     path = request_meta.get("path", "")
                     headers = request_meta.get("headers", {})
 
+                    timeout = kwargs.pop('timeout', self.default_timeout)
+
                     # 获取版本信息
                     version = headers.get('s-y-version')
 
@@ -120,7 +123,7 @@ def feign_client(service_name: str, path_prefix: str = ""):
                                 headers=headers,
                                 params=params,
                                 data=data,
-                                timeout=10
+                                timeout=timeout
                             ) as response:
                                 return await self._handle_response(response)
                         else:
@@ -131,7 +134,7 @@ def feign_client(service_name: str, path_prefix: str = ""):
                                 headers=headers,
                                 params=params,
                                 json=body,
-                                timeout=10
+                                timeout=timeout
                             ) as response:
                                 return await self._handle_response(response)
                     except Exception as e:
@@ -188,15 +191,15 @@ def feign_upload(field_name: str = "file"):
 
 
 async def feign(service_name, api_path, method='GET', params=None, headers=None, file_path=None,
-                path_params=None, request=None, body=None, files=None, form_data=None):
+                path_params=None, body=None, files=None, form_data=None, timeout=None):
     """
-    feign 函数，支持 form-data 表单上传文件和其他字段
+    feign 函数，支持 form-data 表单上传文件和其他字段，支持自定义超时时间
 
     参数:
         files: 字典，用于上传文件，格式: {'field_name': (filename, file_content)}
         form_data: 字典，用于上传表单字段
+        timeout: 超时时间（秒），None 表示不设置超时
     """
-    file_stream = None
     session = aiohttp.ClientSession()
     try:
         # 获取健康的服务实例
@@ -259,7 +262,7 @@ async def feign(service_name, api_path, method='GET', params=None, headers=None,
                         headers=headers,
                         params=params,
                         data=data,
-                        timeout=10
+                        timeout=timeout
                     ) as response:
                         return await _handle_feign_response(response)
                 else:
@@ -272,7 +275,7 @@ async def feign(service_name, api_path, method='GET', params=None, headers=None,
                         headers=headers,
                         params=params,
                         json=body,
-                        timeout=10
+                        timeout=timeout
                     ) as response:
                         return await _handle_feign_response(response)
             except aiohttp.ClientError as e:
@@ -281,8 +284,9 @@ async def feign(service_name, api_path, method='GET', params=None, headers=None,
                 print(f"请求服务接口时出错: {e}")
                 return None
     except Exception as e:
-        SYLogger.error(f"nacos:请求服务接口时出错: {e}")
-        print(f"nacos:请求服务接口时出错: {e}")
+        import traceback
+        SYLogger.error(f"nacos:请求服务接口时出错: {traceback.format_exc()}")
+        print(f"nacos:请求服务接口时出错: {traceback.format_exc()}")
         return None
     finally:
         SYLogger.info(f"nacos:结束调用服务: {service_name}， {api_path}")
